@@ -33,6 +33,8 @@ class _FlaskTrace:
 
         @app.before_request
         def init_session():  # pylint: disable=unused-variable
+            if request.path == "/":
+                return
             trace_context = self.extractor()
             if "tracer" in trace_context:
                 trace_context["tracer"].start_span(name=request.url)
